Class: Aws::ConnectCampaignsV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCampaignsV2::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcampaignsv2/client.rb,
sig/client.rbs
Overview
An API client for ConnectCampaignsV2. To construct a client, you need to configure a :region and :credentials.
client = Aws::ConnectCampaignsV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateCampaignResponseSuccess, _DescribeCampaignResponseSuccess, _GetCampaignStateBatchResponseSuccess, _GetCampaignStateResponseSuccess, _GetConnectInstanceConfigResponseSuccess, _GetInstanceCommunicationLimitsResponseSuccess, _GetInstanceOnboardingJobStatusResponseSuccess, _ListCampaignsResponseSuccess, _ListConnectInstanceIntegrationsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutOutboundRequestBatchResponseSuccess, _PutProfileOutboundRequestBatchResponseSuccess, _StartInstanceOnboardingJobResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account.
-
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
-
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign.
-
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign.
-
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign.
-
#delete_campaign_entry_limits(params = {}) ⇒ Struct
Deletes the entry limits config for a campaign.
-
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
-
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
-
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
-
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
-
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
-
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
-
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
-
#get_instance_communication_limits(params = {}) ⇒ Types::GetInstanceCommunicationLimitsResponse
Get the instance communication limits.
-
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
-
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
-
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
-
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
-
#put_instance_communication_limits(params = {}) ⇒ Struct
Put the instance communication limits.
-
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account.
-
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign.
-
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
-
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
-
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
-
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign.
-
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign.
-
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign.
-
#update_campaign_entry_limits(params = {}) ⇒ Struct
Updates the entry limits config for a campaign.
-
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign.
-
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign.
-
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign.
-
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2157 2158 2159 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2157 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2160 2161 2162 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2160 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2130 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCampaignsV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcampaignsv2' context[:gem_version] = '1.29.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account. This API is idempotent.
88 |
# File 'sig/client.rbs', line 88
def create_campaign: (
|
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
116 |
# File 'sig/client.rbs', line 116
def delete_campaign: (
|
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign. This API is idempotent.
122 |
# File 'sig/client.rbs', line 122
def delete_campaign_channel_subtype_config: (
|
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign. This API is idempotent.
129 |
# File 'sig/client.rbs', line 129
def delete_campaign_communication_limits: (
|
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign. This API is idempotent.
136 |
# File 'sig/client.rbs', line 136
def delete_campaign_communication_time: (
|
#delete_campaign_entry_limits(params = {}) ⇒ Struct
Deletes the entry limits config for a campaign. This API is idempotent.
143 |
# File 'sig/client.rbs', line 143
def delete_campaign_entry_limits: (
|
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
149 |
# File 'sig/client.rbs', line 149
def delete_connect_instance_config: (
|
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
156 |
# File 'sig/client.rbs', line 156
def delete_connect_instance_integration: (
|
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
173 |
# File 'sig/client.rbs', line 173
def delete_instance_onboarding_job: (
|
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
183 |
# File 'sig/client.rbs', line 183
def describe_campaign: (
|
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
193 |
# File 'sig/client.rbs', line 193
def get_campaign_state: (
|
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
204 |
# File 'sig/client.rbs', line 204
def get_campaign_state_batch: (
|
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
214 |
# File 'sig/client.rbs', line 214
def get_connect_instance_config: (
|
#get_instance_communication_limits(params = {}) ⇒ Types::GetInstanceCommunicationLimitsResponse
Get the instance communication limits.
224 |
# File 'sig/client.rbs', line 224
def get_instance_communication_limits: (
|
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
234 |
# File 'sig/client.rbs', line 234
def get_instance_onboarding_job_status: (
|
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
245 |
# File 'sig/client.rbs', line 245
def list_campaigns: (
|
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
263 |
# File 'sig/client.rbs', line 263
def list_connect_instance_integrations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
275 |
# File 'sig/client.rbs', line 275
def list_tags_for_resource: (
|
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
281 |
# File 'sig/client.rbs', line 281
def pause_campaign: (
|
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
287 |
# File 'sig/client.rbs', line 287
def put_connect_instance_integration: (
|
#put_instance_communication_limits(params = {}) ⇒ Struct
Put the instance communication limits. This API is idempotent.
305 |
# File 'sig/client.rbs', line 305
def put_instance_communication_limits: (
|
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account. This API is idempotent.
327 |
# File 'sig/client.rbs', line 327
def put_outbound_request_batch: (
|
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign. This API is idempotent.
374 |
# File 'sig/client.rbs', line 374
def put_profile_outbound_request_batch: (
|
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
396 |
# File 'sig/client.rbs', line 396
def resume_campaign: (
|
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
402 |
# File 'sig/client.rbs', line 402
def start_campaign: (
|
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
412 |
# File 'sig/client.rbs', line 412
def start_instance_onboarding_job: (
|
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
423 |
# File 'sig/client.rbs', line 423
def stop_campaign: (
|
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
429 |
# File 'sig/client.rbs', line 429
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
436 |
# File 'sig/client.rbs', line 436
def untag_resource: (
|
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign. This API is idempotent.
443 |
# File 'sig/client.rbs', line 443
def update_campaign_channel_subtype_config: (
|
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign. This API is idempotent.
450 |
# File 'sig/client.rbs', line 450
def update_campaign_communication_limits: (
|
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign. This API is idempotent.
457 |
# File 'sig/client.rbs', line 457
def update_campaign_communication_time: (
|
#update_campaign_entry_limits(params = {}) ⇒ Struct
Updates the entry limits config for a campaign. This API is idempotent.
464 |
# File 'sig/client.rbs', line 464
def update_campaign_entry_limits: (
|
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign. This API is idempotent.
474 |
# File 'sig/client.rbs', line 474
def update_campaign_flow_association: (
|
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign. This API is idempotent.
481 |
# File 'sig/client.rbs', line 481
def update_campaign_name: (
|
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign. This API is idempotent.
488 |
# File 'sig/client.rbs', line 488
def update_campaign_schedule: (
|
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign. This API is idempotent.
499 |
# File 'sig/client.rbs', line 499
def update_campaign_source: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2150 2151 2152 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2150 def waiter_names [] end |