Class: Aws::ConnectCampaignsV2::Types::AccessDeniedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::AccessDeniedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
You do not have sufficient access to perform this action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#x_amz_error_type ⇒ String
A header that defines the error encountered while processing the request.
Instance Attribute Details
#message ⇒ String
55 56 57 58 59 60 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 55 class AccessDeniedException < Struct.new( :message, :x_amz_error_type) SENSITIVE = [] include Aws::Structure end |
#x_amz_error_type ⇒ String
A header that defines the error encountered while processing the request.
55 56 57 58 59 60 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 55 class AccessDeniedException < Struct.new( :message, :x_amz_error_type) SENSITIVE = [] include Aws::Structure end |