Class: Aws::ConnectCampaignsV2::Types::CommunicationLimit
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::CommunicationLimit
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Communication Limit
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#frequency ⇒ Integer
The number of days to consider with regards to this limit.
-
#max_count_per_recipient ⇒ Integer
Maximum number of contacts allowed for a given target within the given frequency.
-
#unit ⇒ String
The communication limit time unit.
Instance Attribute Details
#frequency ⇒ Integer
The number of days to consider with regards to this limit.
286 287 288 289 290 291 292 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 286 class CommunicationLimit < Struct.new( :max_count_per_recipient, :frequency, :unit) SENSITIVE = [] include Aws::Structure end |
#max_count_per_recipient ⇒ Integer
Maximum number of contacts allowed for a given target within the given frequency.
286 287 288 289 290 291 292 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 286 class CommunicationLimit < Struct.new( :max_count_per_recipient, :frequency, :unit) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The communication limit time unit.
286 287 288 289 290 291 292 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 286 class CommunicationLimit < Struct.new( :max_count_per_recipient, :frequency, :unit) SENSITIVE = [] include Aws::Structure end |