Class: Aws::ConnectCampaignsV2::Types::EntryLimitsConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcampaignsv2/types.rb

Overview

Campaign entry limits config

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_entry_countInteger

Maximum number of times a participant can enter the campaign. A value of 0 indicates unlimited entries. Values of 1 or greater specify the exact number of entries allowed.

Returns:

  • (Integer)


841
842
843
844
845
846
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 841

class EntryLimitsConfig < Struct.new(
  :max_entry_count,
  :min_entry_interval)
  SENSITIVE = []
  include Aws::Structure
end

#min_entry_intervalString

Minimum time interval that must pass before a participant can enter the campaign again.

Returns:

  • (String)


841
842
843
844
845
846
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 841

class EntryLimitsConfig < Struct.new(
  :max_entry_count,
  :min_entry_interval)
  SENSITIVE = []
  include Aws::Structure
end