Class: Aws::ConnectCampaignsV2::Types::IntegrationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::IntegrationSummary
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Note:
IntegrationSummary is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of IntegrationSummary corresponding to the set member.
Integration summary for Connect instance.
Direct Known Subclasses
Defined Under Namespace
Classes: CustomerProfiles, QConnect, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_profiles ⇒ Types::CustomerProfilesIntegrationSummary
Customer Profiles integration summary.
-
#q_connect ⇒ Types::QConnectIntegrationSummary
Q Connect integration summary.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#customer_profiles ⇒ Types::CustomerProfilesIntegrationSummary
Customer Profiles integration summary
1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1062 class IntegrationSummary < Struct.new( :customer_profiles, :q_connect, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerProfiles < IntegrationSummary; end class QConnect < IntegrationSummary; end class Unknown < IntegrationSummary; end end |
#q_connect ⇒ Types::QConnectIntegrationSummary
Q Connect integration summary
1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1062 class IntegrationSummary < Struct.new( :customer_profiles, :q_connect, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerProfiles < IntegrationSummary; end class QConnect < IntegrationSummary; end class Unknown < IntegrationSummary; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1062 1063 1064 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1062 def unknown @unknown end |