Class: Aws::ConnectCampaignsV2::Types::OpenHours

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connectcampaignsv2/types.rb

Overview

Note:

OpenHours is a union - when making an API calls you must set exactly one of the members.

Note:

OpenHours is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OpenHours corresponding to the set member.

Open Hours config

Defined Under Namespace

Classes: DailyHours, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#daily_hoursHash<String,Array<Types::TimeRange>>

Daily Hours map

Returns:



1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1581

class OpenHours < Struct.new(
  :daily_hours,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DailyHours < OpenHours; end
  class Unknown < OpenHours; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1581
1582
1583
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1581

def unknown
  @unknown
end