Class: Aws::ConnectCampaignsV2::Types::RestrictedPeriods
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::RestrictedPeriods
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Note:
RestrictedPeriods is a union - when making an API calls you must set exactly one of the members.
Note:
RestrictedPeriods is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RestrictedPeriods corresponding to the set member.
Restricted period config
Direct Known Subclasses
Defined Under Namespace
Classes: RestrictedPeriodList, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#restricted_period_list ⇒ Array<Types::RestrictedPeriod>
List of restricted period.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#restricted_period_list ⇒ Array<Types::RestrictedPeriod>
List of restricted period
1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1851 class RestrictedPeriods < Struct.new( :restricted_period_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RestrictedPeriodList < RestrictedPeriods; end class Unknown < RestrictedPeriods; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1851 1852 1853 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1851 def unknown @unknown end |