Class: Aws::ConnectCampaignsV2::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Request would cause a service quota to be exceeded.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#x_amz_error_type ⇒ String
A header that defines the error encountered while processing the request.
Instance Attribute Details
#message ⇒ String
1912 1913 1914 1915 1916 1917 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1912 class ServiceQuotaExceededException < Struct.new( :message, :x_amz_error_type) SENSITIVE = [] include Aws::Structure end |
#x_amz_error_type ⇒ String
A header that defines the error encountered while processing the request.
1912 1913 1914 1915 1916 1917 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1912 class ServiceQuotaExceededException < Struct.new( :message, :x_amz_error_type) SENSITIVE = [] include Aws::Structure end |