Class: Aws::ConnectCampaignsV2::Types::Source
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::Source
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Note:
Source is a union - when making an API calls you must set exactly one of the members.
Note:
Source is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Source corresponding to the set member.
Source of the campaign
Defined Under Namespace
Classes: CustomerProfilesSegmentArn, EventTrigger, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_profiles_segment_arn ⇒ String
Amazon Resource Names(ARN).
-
#event_trigger ⇒ Types::EventTrigger
Event trigger of the campaign.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#customer_profiles_segment_arn ⇒ String
Amazon Resource Names(ARN)
2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2076 class Source < Struct.new( :customer_profiles_segment_arn, :event_trigger, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerProfilesSegmentArn < Source; end class EventTrigger < Source; end class Unknown < Source; end end |
#event_trigger ⇒ Types::EventTrigger
Event trigger of the campaign
2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2076 class Source < Struct.new( :customer_profiles_segment_arn, :event_trigger, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerProfilesSegmentArn < Source; end class EventTrigger < Source; end class Unknown < Source; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2076 2077 2078 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2076 def unknown @unknown end |