Class: Aws::ConnectCampaignsV2::Types::TelephonyChannelSubtypeParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::TelephonyChannelSubtypeParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Parameters for the Telephony Channel Subtype
Constant Summary collapse
- SENSITIVE =
[:destination_phone_number, :attributes]
Instance Attribute Summary collapse
-
#answer_machine_detection_config ⇒ Types::AnswerMachineDetectionConfig
Answering Machine Detection config.
-
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map.
-
#connect_source_phone_number ⇒ String
The phone number associated with the Amazon Connect instance, in E.164 format.
-
#destination_phone_number ⇒ String
The phone number of the customer, in E.164 format.
-
#ring_timeout ⇒ Integer
Ring timeout for outbound calls.
Instance Attribute Details
#answer_machine_detection_config ⇒ Types::AnswerMachineDetectionConfig
Answering Machine Detection config
2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2293 class TelephonyChannelSubtypeParameters < Struct.new( :destination_phone_number, :attributes, :connect_source_phone_number, :answer_machine_detection_config, :ring_timeout) SENSITIVE = [:destination_phone_number, :attributes] include Aws::Structure end |
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map. The attributes are standard Amazon Connect attributes, and can be accessed in contact flows just like any other contact attributes.
2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2293 class TelephonyChannelSubtypeParameters < Struct.new( :destination_phone_number, :attributes, :connect_source_phone_number, :answer_machine_detection_config, :ring_timeout) SENSITIVE = [:destination_phone_number, :attributes] include Aws::Structure end |
#connect_source_phone_number ⇒ String
The phone number associated with the Amazon Connect instance, in E.164 format. If you do not specify a source phone number, you must specify a queue.
2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2293 class TelephonyChannelSubtypeParameters < Struct.new( :destination_phone_number, :attributes, :connect_source_phone_number, :answer_machine_detection_config, :ring_timeout) SENSITIVE = [:destination_phone_number, :attributes] include Aws::Structure end |
#destination_phone_number ⇒ String
The phone number of the customer, in E.164 format.
2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2293 class TelephonyChannelSubtypeParameters < Struct.new( :destination_phone_number, :attributes, :connect_source_phone_number, :answer_machine_detection_config, :ring_timeout) SENSITIVE = [:destination_phone_number, :attributes] include Aws::Structure end |
#ring_timeout ⇒ Integer
Ring timeout for outbound calls
2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2293 class TelephonyChannelSubtypeParameters < Struct.new( :destination_phone_number, :attributes, :connect_source_phone_number, :answer_machine_detection_config, :ring_timeout) SENSITIVE = [:destination_phone_number, :attributes] include Aws::Structure end |