Class: Aws::ConnectCampaignsV2::Types::TelephonyOutboundConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcampaignsv2/types.rb

Overview

Default Telephony Outbound config

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#answer_machine_detection_configTypes::AnswerMachineDetectionConfig

Answering Machine Detection config



1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1913

class TelephonyOutboundConfig < Struct.new(
  :connect_contact_flow_id,
  :connect_source_phone_number,
  :answer_machine_detection_config)
  SENSITIVE = []
  include Aws::Structure
end

#connect_contact_flow_idString

The identifier of the contact flow for the outbound call.

Returns:

  • (String)


1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1913

class TelephonyOutboundConfig < Struct.new(
  :connect_contact_flow_id,
  :connect_source_phone_number,
  :answer_machine_detection_config)
  SENSITIVE = []
  include Aws::Structure
end

#connect_source_phone_numberString

The phone number associated with the Amazon Connect instance, in E.164 format. If you do not specify a source phone number, you must specify a queue.

Returns:

  • (String)


1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1913

class TelephonyOutboundConfig < Struct.new(
  :connect_contact_flow_id,
  :connect_source_phone_number,
  :answer_machine_detection_config)
  SENSITIVE = []
  include Aws::Structure
end