Class: Aws::ConnectCampaignsV2::Types::WhatsAppChannelSubtypeParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::WhatsAppChannelSubtypeParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Parameters for the WhatsApp Channel Subtype
Constant Summary collapse
- SENSITIVE =
[:destination_phone_number, :template_parameters]
Instance Attribute Summary collapse
-
#connect_source_phone_number_arn ⇒ String
Amazon Resource Names(ARN).
-
#destination_phone_number ⇒ String
The phone number of the customer, in E.164 format.
-
#template_arn ⇒ String
Amazon Resource Names(ARN).
-
#template_parameters ⇒ Hash<String,String>
A custom key-value pair using an attribute map.
Instance Attribute Details
#connect_source_phone_number_arn ⇒ String
Amazon Resource Names(ARN)
2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2761 class WhatsAppChannelSubtypeParameters < Struct.new( :destination_phone_number, :connect_source_phone_number_arn, :template_arn, :template_parameters) SENSITIVE = [:destination_phone_number, :template_parameters] include Aws::Structure end |
#destination_phone_number ⇒ String
The phone number of the customer, in E.164 format.
2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2761 class WhatsAppChannelSubtypeParameters < Struct.new( :destination_phone_number, :connect_source_phone_number_arn, :template_arn, :template_parameters) SENSITIVE = [:destination_phone_number, :template_parameters] include Aws::Structure end |
#template_arn ⇒ String
Amazon Resource Names(ARN)
2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2761 class WhatsAppChannelSubtypeParameters < Struct.new( :destination_phone_number, :connect_source_phone_number_arn, :template_arn, :template_parameters) SENSITIVE = [:destination_phone_number, :template_parameters] include Aws::Structure end |
#template_parameters ⇒ Hash<String,String>
A custom key-value pair using an attribute map. The attributes are standard Amazon Connect attributes, and can be accessed in contact flows just like any other contact attributes.
2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2761 class WhatsAppChannelSubtypeParameters < Struct.new( :destination_phone_number, :connect_source_phone_number_arn, :template_arn, :template_parameters) SENSITIVE = [:destination_phone_number, :template_parameters] include Aws::Structure end |