Class: Aws::ConnectCampaignsV2::Types::WhatsAppOutboundMode
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::WhatsAppOutboundMode
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Note:
WhatsAppOutboundMode is a union - when making an API calls you must set exactly one of the members.
Note:
WhatsAppOutboundMode is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WhatsAppOutboundMode corresponding to the set member.
WhatsApp Outbound Mode
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agentless ⇒ Types::AgentlessConfig
Agentless config.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agentless ⇒ Types::AgentlessConfig
Agentless config
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2801 class WhatsAppOutboundMode < Struct.new( :agentless, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Agentless < WhatsAppOutboundMode; end class Unknown < WhatsAppOutboundMode; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2801 2802 2803 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2801 def unknown @unknown end |