Class: Aws::ConnectCampaignsV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCampaignsV2::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcampaignsv2/client.rb
Overview
An API client for ConnectCampaignsV2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ConnectCampaignsV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account.
-
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
-
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign.
-
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign.
-
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign.
-
#delete_campaign_entry_limits(params = {}) ⇒ Struct
Deletes the entry limits config for a campaign.
-
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
-
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
-
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
-
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
-
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
-
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
-
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
-
#get_instance_communication_limits(params = {}) ⇒ Types::GetInstanceCommunicationLimitsResponse
Get the instance communication limits.
-
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
-
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
-
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
-
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
-
#put_instance_communication_limits(params = {}) ⇒ Struct
Put the instance communication limits.
-
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account.
-
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign.
-
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
-
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
-
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
-
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign.
-
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign.
-
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign.
-
#update_campaign_entry_limits(params = {}) ⇒ Struct
Updates the entry limits config for a campaign.
-
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign.
-
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign.
-
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign.
-
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2150 2151 2152 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2150 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2153 2154 2155 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2153 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2123 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCampaignsV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcampaignsv2' context[:gem_version] = '1.26.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account. This API is idempotent.
728 729 730 731 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 728 def create_campaign(params = {}, = {}) req = build_request(:create_campaign, params) req.send_request() end |
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
750 751 752 753 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 750 def delete_campaign(params = {}, = {}) req = build_request(:delete_campaign, params) req.send_request() end |
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign. This API is idempotent.
777 778 779 780 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 777 def delete_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:delete_campaign_channel_subtype_config, params) req.send_request() end |
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign. This API is idempotent.
804 805 806 807 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 804 def delete_campaign_communication_limits(params = {}, = {}) req = build_request(:delete_campaign_communication_limits, params) req.send_request() end |
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign. This API is idempotent.
831 832 833 834 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 831 def delete_campaign_communication_time(params = {}, = {}) req = build_request(:delete_campaign_communication_time, params) req.send_request() end |
#delete_campaign_entry_limits(params = {}) ⇒ Struct
Deletes the entry limits config for a campaign. This API is idempotent.
854 855 856 857 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 854 def delete_campaign_entry_limits(params = {}, = {}) req = build_request(:delete_campaign_entry_limits, params) req.send_request() end |
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
881 882 883 884 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 881 def delete_connect_instance_config(params = {}, = {}) req = build_request(:delete_connect_instance_config, params) req.send_request() end |
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
917 918 919 920 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 917 def delete_connect_instance_integration(params = {}, = {}) req = build_request(:delete_connect_instance_integration, params) req.send_request() end |
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
940 941 942 943 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 940 def delete_instance_onboarding_job(params = {}, = {}) req = build_request(:delete_instance_onboarding_job, params) req.send_request() end |
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
1046 1047 1048 1049 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1046 def describe_campaign(params = {}, = {}) req = build_request(:describe_campaign, params) req.send_request() end |
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
1074 1075 1076 1077 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1074 def get_campaign_state(params = {}, = {}) req = build_request(:get_campaign_state, params) req.send_request() end |
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
1108 1109 1110 1111 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1108 def get_campaign_state_batch(params = {}, = {}) req = build_request(:get_campaign_state_batch, params) req.send_request() end |
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
1140 1141 1142 1143 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1140 def get_connect_instance_config(params = {}, = {}) req = build_request(:get_connect_instance_config, params) req.send_request() end |
#get_instance_communication_limits(params = {}) ⇒ Types::GetInstanceCommunicationLimitsResponse
Get the instance communication limits.
1171 1172 1173 1174 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1171 def get_instance_communication_limits(params = {}, = {}) req = build_request(:get_instance_communication_limits, params) req.send_request() end |
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
1201 1202 1203 1204 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1201 def get_instance_onboarding_job_status(params = {}, = {}) req = build_request(:get_instance_onboarding_job_status, params) req.send_request() end |
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1260 1261 1262 1263 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1260 def list_campaigns(params = {}, = {}) req = build_request(:list_campaigns, params) req.send_request() end |
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1306 1307 1308 1309 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1306 def list_connect_instance_integrations(params = {}, = {}) req = build_request(:list_connect_instance_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
1335 1336 1337 1338 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1335 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
1357 1358 1359 1360 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1357 def pause_campaign(params = {}, = {}) req = build_request(:pause_campaign, params) req.send_request() end |
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
1397 1398 1399 1400 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1397 def put_connect_instance_integration(params = {}, = {}) req = build_request(:put_connect_instance_integration, params) req.send_request() end |
#put_instance_communication_limits(params = {}) ⇒ Struct
Put the instance communication limits. This API is idempotent.
1433 1434 1435 1436 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1433 def put_instance_communication_limits(params = {}, = {}) req = build_request(:put_instance_communication_limits, params) req.send_request() end |
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account. This API is idempotent.
1516 1517 1518 1519 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1516 def put_outbound_request_batch(params = {}, = {}) req = build_request(:put_outbound_request_batch, params) req.send_request() end |
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign. This API is idempotent.
1562 1563 1564 1565 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1562 def put_profile_outbound_request_batch(params = {}, = {}) req = build_request(:put_profile_outbound_request_batch, params) req.send_request() end |
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1584 1585 1586 1587 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1584 def resume_campaign(params = {}, = {}) req = build_request(:resume_campaign, params) req.send_request() end |
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
1606 1607 1608 1609 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1606 def start_campaign(params = {}, = {}) req = build_request(:start_campaign, params) req.send_request() end |
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
1647 1648 1649 1650 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1647 def start_instance_onboarding_job(params = {}, = {}) req = build_request(:start_instance_onboarding_job, params) req.send_request() end |
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1669 1670 1671 1672 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1669 def stop_campaign(params = {}, = {}) req = build_request(:stop_campaign, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
1697 1698 1699 1700 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1697 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
1723 1724 1725 1726 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1723 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign. This API is idempotent.
1815 1816 1817 1818 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1815 def update_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:update_campaign_channel_subtype_config, params) req.send_request() end |
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign. This API is idempotent.
1853 1854 1855 1856 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1853 def update_campaign_communication_limits(params = {}, = {}) req = build_request(:update_campaign_communication_limits, params) req.send_request() end |
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign. This API is idempotent.
1970 1971 1972 1973 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1970 def update_campaign_communication_time(params = {}, = {}) req = build_request(:update_campaign_communication_time, params) req.send_request() end |
#update_campaign_entry_limits(params = {}) ⇒ Struct
Updates the entry limits config for a campaign. This API is idempotent.
2000 2001 2002 2003 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2000 def update_campaign_entry_limits(params = {}, = {}) req = build_request(:update_campaign_entry_limits, params) req.send_request() end |
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign. This API is idempotent.
2027 2028 2029 2030 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2027 def update_campaign_flow_association(params = {}, = {}) req = build_request(:update_campaign_flow_association, params) req.send_request() end |
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign. This API is idempotent.
2053 2054 2055 2056 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2053 def update_campaign_name(params = {}, = {}) req = build_request(:update_campaign_name, params) req.send_request() end |
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign. This API is idempotent.
2083 2084 2085 2086 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2083 def update_campaign_schedule(params = {}, = {}) req = build_request(:update_campaign_schedule, params) req.send_request() end |
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign. This API is idempotent.
2114 2115 2116 2117 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2114 def update_campaign_source(params = {}, = {}) req = build_request(:update_campaign_source, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2143 2144 2145 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2143 def waiter_names [] end |