Class: Aws::ConnectCampaignsV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCampaignsV2::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcampaignsv2/client.rb
Overview
An API client for ConnectCampaignsV2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ConnectCampaignsV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account.
-
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
-
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign.
-
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign.
-
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign.
-
#delete_campaign_entry_limits(params = {}) ⇒ Struct
Deletes the entry limits config for a campaign.
-
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
-
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
-
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
-
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
-
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
-
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
-
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
-
#get_instance_communication_limits(params = {}) ⇒ Types::GetInstanceCommunicationLimitsResponse
Get the instance communication limits.
-
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
-
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
-
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
-
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
-
#put_instance_communication_limits(params = {}) ⇒ Struct
Put the instance communication limits.
-
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account.
-
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign.
-
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
-
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
-
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
-
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign.
-
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign.
-
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign.
-
#update_campaign_entry_limits(params = {}) ⇒ Struct
Updates the entry limits config for a campaign.
-
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign.
-
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign.
-
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign.
-
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2147 2148 2149 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2147 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2150 2151 2152 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2150 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2120 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCampaignsV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcampaignsv2' context[:gem_version] = '1.24.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account. This API is idempotent.
727 728 729 730 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 727 def create_campaign(params = {}, = {}) req = build_request(:create_campaign, params) req.send_request() end |
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
749 750 751 752 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 749 def delete_campaign(params = {}, = {}) req = build_request(:delete_campaign, params) req.send_request() end |
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign. This API is idempotent.
776 777 778 779 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 776 def delete_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:delete_campaign_channel_subtype_config, params) req.send_request() end |
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign. This API is idempotent.
803 804 805 806 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 803 def delete_campaign_communication_limits(params = {}, = {}) req = build_request(:delete_campaign_communication_limits, params) req.send_request() end |
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign. This API is idempotent.
830 831 832 833 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 830 def delete_campaign_communication_time(params = {}, = {}) req = build_request(:delete_campaign_communication_time, params) req.send_request() end |
#delete_campaign_entry_limits(params = {}) ⇒ Struct
Deletes the entry limits config for a campaign. This API is idempotent.
853 854 855 856 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 853 def delete_campaign_entry_limits(params = {}, = {}) req = build_request(:delete_campaign_entry_limits, params) req.send_request() end |
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
880 881 882 883 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 880 def delete_connect_instance_config(params = {}, = {}) req = build_request(:delete_connect_instance_config, params) req.send_request() end |
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
916 917 918 919 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 916 def delete_connect_instance_integration(params = {}, = {}) req = build_request(:delete_connect_instance_integration, params) req.send_request() end |
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
939 940 941 942 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 939 def delete_instance_onboarding_job(params = {}, = {}) req = build_request(:delete_instance_onboarding_job, params) req.send_request() end |
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
1044 1045 1046 1047 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1044 def describe_campaign(params = {}, = {}) req = build_request(:describe_campaign, params) req.send_request() end |
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
1072 1073 1074 1075 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1072 def get_campaign_state(params = {}, = {}) req = build_request(:get_campaign_state, params) req.send_request() end |
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
1106 1107 1108 1109 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1106 def get_campaign_state_batch(params = {}, = {}) req = build_request(:get_campaign_state_batch, params) req.send_request() end |
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
1138 1139 1140 1141 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1138 def get_connect_instance_config(params = {}, = {}) req = build_request(:get_connect_instance_config, params) req.send_request() end |
#get_instance_communication_limits(params = {}) ⇒ Types::GetInstanceCommunicationLimitsResponse
Get the instance communication limits.
1169 1170 1171 1172 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1169 def get_instance_communication_limits(params = {}, = {}) req = build_request(:get_instance_communication_limits, params) req.send_request() end |
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
1199 1200 1201 1202 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1199 def get_instance_onboarding_job_status(params = {}, = {}) req = build_request(:get_instance_onboarding_job_status, params) req.send_request() end |
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1258 1259 1260 1261 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1258 def list_campaigns(params = {}, = {}) req = build_request(:list_campaigns, params) req.send_request() end |
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1304 1305 1306 1307 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1304 def list_connect_instance_integrations(params = {}, = {}) req = build_request(:list_connect_instance_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
1333 1334 1335 1336 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1333 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
1355 1356 1357 1358 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1355 def pause_campaign(params = {}, = {}) req = build_request(:pause_campaign, params) req.send_request() end |
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
1395 1396 1397 1398 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1395 def put_connect_instance_integration(params = {}, = {}) req = build_request(:put_connect_instance_integration, params) req.send_request() end |
#put_instance_communication_limits(params = {}) ⇒ Struct
Put the instance communication limits. This API is idempotent.
1431 1432 1433 1434 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1431 def put_instance_communication_limits(params = {}, = {}) req = build_request(:put_instance_communication_limits, params) req.send_request() end |
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account. This API is idempotent.
1514 1515 1516 1517 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1514 def put_outbound_request_batch(params = {}, = {}) req = build_request(:put_outbound_request_batch, params) req.send_request() end |
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign. This API is idempotent.
1560 1561 1562 1563 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1560 def put_profile_outbound_request_batch(params = {}, = {}) req = build_request(:put_profile_outbound_request_batch, params) req.send_request() end |
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1582 1583 1584 1585 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1582 def resume_campaign(params = {}, = {}) req = build_request(:resume_campaign, params) req.send_request() end |
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
1604 1605 1606 1607 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1604 def start_campaign(params = {}, = {}) req = build_request(:start_campaign, params) req.send_request() end |
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
1645 1646 1647 1648 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1645 def start_instance_onboarding_job(params = {}, = {}) req = build_request(:start_instance_onboarding_job, params) req.send_request() end |
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1667 1668 1669 1670 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1667 def stop_campaign(params = {}, = {}) req = build_request(:stop_campaign, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
1695 1696 1697 1698 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1695 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
1721 1722 1723 1724 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1721 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign. This API is idempotent.
1813 1814 1815 1816 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1813 def update_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:update_campaign_channel_subtype_config, params) req.send_request() end |
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign. This API is idempotent.
1851 1852 1853 1854 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1851 def update_campaign_communication_limits(params = {}, = {}) req = build_request(:update_campaign_communication_limits, params) req.send_request() end |
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign. This API is idempotent.
1967 1968 1969 1970 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1967 def update_campaign_communication_time(params = {}, = {}) req = build_request(:update_campaign_communication_time, params) req.send_request() end |
#update_campaign_entry_limits(params = {}) ⇒ Struct
Updates the entry limits config for a campaign. This API is idempotent.
1997 1998 1999 2000 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1997 def update_campaign_entry_limits(params = {}, = {}) req = build_request(:update_campaign_entry_limits, params) req.send_request() end |
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign. This API is idempotent.
2024 2025 2026 2027 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2024 def update_campaign_flow_association(params = {}, = {}) req = build_request(:update_campaign_flow_association, params) req.send_request() end |
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign. This API is idempotent.
2050 2051 2052 2053 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2050 def update_campaign_name(params = {}, = {}) req = build_request(:update_campaign_name, params) req.send_request() end |
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign. This API is idempotent.
2080 2081 2082 2083 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2080 def update_campaign_schedule(params = {}, = {}) req = build_request(:update_campaign_schedule, params) req.send_request() end |
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign. This API is idempotent.
2111 2112 2113 2114 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2111 def update_campaign_source(params = {}, = {}) req = build_request(:update_campaign_source, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2140 2141 2142 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 2140 def waiter_names [] end |