Class: Aws::ConnectCampaignsV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCampaignsV2::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcampaignsv2/client.rb
Overview
An API client for ConnectCampaignsV2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ConnectCampaignsV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account.
-
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
-
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign.
-
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign.
-
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign.
-
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
-
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
-
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
-
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
-
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
-
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
-
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
-
#get_instance_communication_limits(params = {}) ⇒ Types::GetInstanceCommunicationLimitsResponse
Get the instance communication limits.
-
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
-
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
-
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
-
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
-
#put_instance_communication_limits(params = {}) ⇒ Struct
Put the instance communication limits.
-
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account.
-
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign.
-
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
-
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
-
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
-
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign.
-
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign.
-
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign.
-
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign.
-
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign.
-
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign.
-
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
476 477 478 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 476 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1968 1969 1970 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1968 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1971 1972 1973 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1971 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1941 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCampaignsV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcampaignsv2' context[:gem_version] = '1.9.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account. This API is idempotent.
679 680 681 682 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 679 def create_campaign(params = {}, = {}) req = build_request(:create_campaign, params) req.send_request() end |
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
701 702 703 704 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 701 def delete_campaign(params = {}, = {}) req = build_request(:delete_campaign, params) req.send_request() end |
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign. This API is idempotent.
728 729 730 731 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 728 def delete_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:delete_campaign_channel_subtype_config, params) req.send_request() end |
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign. This API is idempotent.
755 756 757 758 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 755 def delete_campaign_communication_limits(params = {}, = {}) req = build_request(:delete_campaign_communication_limits, params) req.send_request() end |
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign. This API is idempotent.
782 783 784 785 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 782 def delete_campaign_communication_time(params = {}, = {}) req = build_request(:delete_campaign_communication_time, params) req.send_request() end |
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
809 810 811 812 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 809 def delete_connect_instance_config(params = {}, = {}) req = build_request(:delete_connect_instance_config, params) req.send_request() end |
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
842 843 844 845 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 842 def delete_connect_instance_integration(params = {}, = {}) req = build_request(:delete_connect_instance_integration, params) req.send_request() end |
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
865 866 867 868 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 865 def delete_instance_onboarding_job(params = {}, = {}) req = build_request(:delete_instance_onboarding_job, params) req.send_request() end |
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
951 952 953 954 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 951 def describe_campaign(params = {}, = {}) req = build_request(:describe_campaign, params) req.send_request() end |
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
979 980 981 982 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 979 def get_campaign_state(params = {}, = {}) req = build_request(:get_campaign_state, params) req.send_request() end |
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
1013 1014 1015 1016 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1013 def get_campaign_state_batch(params = {}, = {}) req = build_request(:get_campaign_state_batch, params) req.send_request() end |
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
1045 1046 1047 1048 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1045 def get_connect_instance_config(params = {}, = {}) req = build_request(:get_connect_instance_config, params) req.send_request() end |
#get_instance_communication_limits(params = {}) ⇒ Types::GetInstanceCommunicationLimitsResponse
Get the instance communication limits.
1076 1077 1078 1079 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1076 def get_instance_communication_limits(params = {}, = {}) req = build_request(:get_instance_communication_limits, params) req.send_request() end |
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
1106 1107 1108 1109 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1106 def get_instance_onboarding_job_status(params = {}, = {}) req = build_request(:get_instance_onboarding_job_status, params) req.send_request() end |
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1162 1163 1164 1165 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1162 def list_campaigns(params = {}, = {}) req = build_request(:list_campaigns, params) req.send_request() end |
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1207 1208 1209 1210 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1207 def list_connect_instance_integrations(params = {}, = {}) req = build_request(:list_connect_instance_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
1236 1237 1238 1239 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1236 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
1258 1259 1260 1261 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1258 def pause_campaign(params = {}, = {}) req = build_request(:pause_campaign, params) req.send_request() end |
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
1295 1296 1297 1298 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1295 def put_connect_instance_integration(params = {}, = {}) req = build_request(:put_connect_instance_integration, params) req.send_request() end |
#put_instance_communication_limits(params = {}) ⇒ Struct
Put the instance communication limits. This API is idempotent.
1331 1332 1333 1334 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1331 def put_instance_communication_limits(params = {}, = {}) req = build_request(:put_instance_communication_limits, params) req.send_request() end |
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account. This API is idempotent.
1405 1406 1407 1408 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1405 def put_outbound_request_batch(params = {}, = {}) req = build_request(:put_outbound_request_batch, params) req.send_request() end |
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign. This API is idempotent.
1451 1452 1453 1454 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1451 def put_profile_outbound_request_batch(params = {}, = {}) req = build_request(:put_profile_outbound_request_batch, params) req.send_request() end |
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1473 1474 1475 1476 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1473 def resume_campaign(params = {}, = {}) req = build_request(:resume_campaign, params) req.send_request() end |
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
1495 1496 1497 1498 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1495 def start_campaign(params = {}, = {}) req = build_request(:start_campaign, params) req.send_request() end |
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
1536 1537 1538 1539 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1536 def start_instance_onboarding_job(params = {}, = {}) req = build_request(:start_instance_onboarding_job, params) req.send_request() end |
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1558 1559 1560 1561 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1558 def stop_campaign(params = {}, = {}) req = build_request(:stop_campaign, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
1586 1587 1588 1589 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1586 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
1612 1613 1614 1615 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1612 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign. This API is idempotent.
1685 1686 1687 1688 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1685 def update_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:update_campaign_channel_subtype_config, params) req.send_request() end |
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign. This API is idempotent.
1723 1724 1725 1726 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1723 def update_campaign_communication_limits(params = {}, = {}) req = build_request(:update_campaign_communication_limits, params) req.send_request() end |
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign. This API is idempotent.
1818 1819 1820 1821 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1818 def update_campaign_communication_time(params = {}, = {}) req = build_request(:update_campaign_communication_time, params) req.send_request() end |
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign. This API is idempotent.
1845 1846 1847 1848 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1845 def update_campaign_flow_association(params = {}, = {}) req = build_request(:update_campaign_flow_association, params) req.send_request() end |
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign. This API is idempotent.
1871 1872 1873 1874 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1871 def update_campaign_name(params = {}, = {}) req = build_request(:update_campaign_name, params) req.send_request() end |
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign. This API is idempotent.
1901 1902 1903 1904 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1901 def update_campaign_schedule(params = {}, = {}) req = build_request(:update_campaign_schedule, params) req.send_request() end |
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign. This API is idempotent.
1932 1933 1934 1935 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1932 def update_campaign_source(params = {}, = {}) req = build_request(:update_campaign_source, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1961 1962 1963 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1961 def waiter_names [] end |