Class: Aws::ConnectCampaignsV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCampaignsV2::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcampaignsv2/client.rb
Overview
An API client for ConnectCampaignsV2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ConnectCampaignsV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account.
-
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
-
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign.
-
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign.
-
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign.
-
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
-
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
-
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
-
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
-
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
-
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
-
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
-
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
-
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
-
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
-
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
-
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account.
-
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign.
-
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
-
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
-
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
-
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign.
-
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign.
-
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign.
-
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign.
-
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign.
-
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign.
-
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
466 467 468 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 466 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1888 1889 1890 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1888 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1891 1892 1893 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1891 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1861 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCampaignsV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcampaignsv2' context[:gem_version] = '1.6.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account. This API is idempotent.
668 669 670 671 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 668 def create_campaign(params = {}, = {}) req = build_request(:create_campaign, params) req.send_request() end |
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
690 691 692 693 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 690 def delete_campaign(params = {}, = {}) req = build_request(:delete_campaign, params) req.send_request() end |
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign. This API is idempotent.
717 718 719 720 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 717 def delete_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:delete_campaign_channel_subtype_config, params) req.send_request() end |
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign. This API is idempotent.
744 745 746 747 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 744 def delete_campaign_communication_limits(params = {}, = {}) req = build_request(:delete_campaign_communication_limits, params) req.send_request() end |
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign. This API is idempotent.
771 772 773 774 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 771 def delete_campaign_communication_time(params = {}, = {}) req = build_request(:delete_campaign_communication_time, params) req.send_request() end |
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
798 799 800 801 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 798 def delete_connect_instance_config(params = {}, = {}) req = build_request(:delete_connect_instance_config, params) req.send_request() end |
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
831 832 833 834 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 831 def delete_connect_instance_integration(params = {}, = {}) req = build_request(:delete_connect_instance_integration, params) req.send_request() end |
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
854 855 856 857 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 854 def delete_instance_onboarding_job(params = {}, = {}) req = build_request(:delete_instance_onboarding_job, params) req.send_request() end |
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
939 940 941 942 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 939 def describe_campaign(params = {}, = {}) req = build_request(:describe_campaign, params) req.send_request() end |
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
967 968 969 970 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 967 def get_campaign_state(params = {}, = {}) req = build_request(:get_campaign_state, params) req.send_request() end |
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
1001 1002 1003 1004 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1001 def get_campaign_state_batch(params = {}, = {}) req = build_request(:get_campaign_state_batch, params) req.send_request() end |
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
1033 1034 1035 1036 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1033 def get_connect_instance_config(params = {}, = {}) req = build_request(:get_connect_instance_config, params) req.send_request() end |
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
1063 1064 1065 1066 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1063 def get_instance_onboarding_job_status(params = {}, = {}) req = build_request(:get_instance_onboarding_job_status, params) req.send_request() end |
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1119 1120 1121 1122 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1119 def list_campaigns(params = {}, = {}) req = build_request(:list_campaigns, params) req.send_request() end |
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1164 1165 1166 1167 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1164 def list_connect_instance_integrations(params = {}, = {}) req = build_request(:list_connect_instance_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
1193 1194 1195 1196 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1193 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
1215 1216 1217 1218 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1215 def pause_campaign(params = {}, = {}) req = build_request(:pause_campaign, params) req.send_request() end |
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
1252 1253 1254 1255 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1252 def put_connect_instance_integration(params = {}, = {}) req = build_request(:put_connect_instance_integration, params) req.send_request() end |
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account. This API is idempotent.
1326 1327 1328 1329 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1326 def put_outbound_request_batch(params = {}, = {}) req = build_request(:put_outbound_request_batch, params) req.send_request() end |
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign. This API is idempotent.
1372 1373 1374 1375 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1372 def put_profile_outbound_request_batch(params = {}, = {}) req = build_request(:put_profile_outbound_request_batch, params) req.send_request() end |
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1394 1395 1396 1397 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1394 def resume_campaign(params = {}, = {}) req = build_request(:resume_campaign, params) req.send_request() end |
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
1416 1417 1418 1419 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1416 def start_campaign(params = {}, = {}) req = build_request(:start_campaign, params) req.send_request() end |
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
1457 1458 1459 1460 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1457 def start_instance_onboarding_job(params = {}, = {}) req = build_request(:start_instance_onboarding_job, params) req.send_request() end |
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1479 1480 1481 1482 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1479 def stop_campaign(params = {}, = {}) req = build_request(:stop_campaign, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
1507 1508 1509 1510 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1507 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
1533 1534 1535 1536 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1533 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign. This API is idempotent.
1606 1607 1608 1609 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1606 def update_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:update_campaign_channel_subtype_config, params) req.send_request() end |
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign. This API is idempotent.
1643 1644 1645 1646 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1643 def update_campaign_communication_limits(params = {}, = {}) req = build_request(:update_campaign_communication_limits, params) req.send_request() end |
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign. This API is idempotent.
1738 1739 1740 1741 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1738 def update_campaign_communication_time(params = {}, = {}) req = build_request(:update_campaign_communication_time, params) req.send_request() end |
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign. This API is idempotent.
1765 1766 1767 1768 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1765 def update_campaign_flow_association(params = {}, = {}) req = build_request(:update_campaign_flow_association, params) req.send_request() end |
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign. This API is idempotent.
1791 1792 1793 1794 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1791 def update_campaign_name(params = {}, = {}) req = build_request(:update_campaign_name, params) req.send_request() end |
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign. This API is idempotent.
1821 1822 1823 1824 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1821 def update_campaign_schedule(params = {}, = {}) req = build_request(:update_campaign_schedule, params) req.send_request() end |
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign. This API is idempotent.
1852 1853 1854 1855 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1852 def update_campaign_source(params = {}, = {}) req = build_request(:update_campaign_source, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1881 1882 1883 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1881 def waiter_names [] end |