Class: Aws::ConnectCampaignsV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCampaignsV2::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcampaignsv2/client.rb
Overview
An API client for ConnectCampaignsV2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ConnectCampaignsV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account.
-
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
-
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign.
-
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign.
-
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign.
-
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
-
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
-
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
-
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
-
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
-
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
-
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
-
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
-
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
-
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
-
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
-
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account.
-
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign.
-
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
-
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
-
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
-
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign.
-
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign.
-
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign.
-
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign.
-
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign.
-
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign.
-
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
467 468 469 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 467 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1889 1890 1891 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1889 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1892 1893 1894 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1892 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1862 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCampaignsV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcampaignsv2' context[:gem_version] = '1.3.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account. This API is idempotent.
669 670 671 672 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 669 def create_campaign(params = {}, = {}) req = build_request(:create_campaign, params) req.send_request() end |
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
691 692 693 694 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 691 def delete_campaign(params = {}, = {}) req = build_request(:delete_campaign, params) req.send_request() end |
#delete_campaign_channel_subtype_config(params = {}) ⇒ Struct
Deletes the channel subtype config of a campaign. This API is idempotent.
718 719 720 721 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 718 def delete_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:delete_campaign_channel_subtype_config, params) req.send_request() end |
#delete_campaign_communication_limits(params = {}) ⇒ Struct
Deletes the communication limits config for a campaign. This API is idempotent.
745 746 747 748 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 745 def delete_campaign_communication_limits(params = {}, = {}) req = build_request(:delete_campaign_communication_limits, params) req.send_request() end |
#delete_campaign_communication_time(params = {}) ⇒ Struct
Deletes the communication time config for a campaign. This API is idempotent.
772 773 774 775 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 772 def delete_campaign_communication_time(params = {}, = {}) req = build_request(:delete_campaign_communication_time, params) req.send_request() end |
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
799 800 801 802 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 799 def delete_connect_instance_config(params = {}, = {}) req = build_request(:delete_connect_instance_config, params) req.send_request() end |
#delete_connect_instance_integration(params = {}) ⇒ Struct
Delete the integration for the specified Amazon Connect instance.
832 833 834 835 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 832 def delete_connect_instance_integration(params = {}, = {}) req = build_request(:delete_connect_instance_integration, params) req.send_request() end |
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
855 856 857 858 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 855 def delete_instance_onboarding_job(params = {}, = {}) req = build_request(:delete_instance_onboarding_job, params) req.send_request() end |
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
940 941 942 943 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 940 def describe_campaign(params = {}, = {}) req = build_request(:describe_campaign, params) req.send_request() end |
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
968 969 970 971 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 968 def get_campaign_state(params = {}, = {}) req = build_request(:get_campaign_state, params) req.send_request() end |
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
1002 1003 1004 1005 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1002 def get_campaign_state_batch(params = {}, = {}) req = build_request(:get_campaign_state_batch, params) req.send_request() end |
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
1034 1035 1036 1037 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1034 def get_connect_instance_config(params = {}, = {}) req = build_request(:get_connect_instance_config, params) req.send_request() end |
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
1064 1065 1066 1067 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1064 def get_instance_onboarding_job_status(params = {}, = {}) req = build_request(:get_instance_onboarding_job_status, params) req.send_request() end |
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1120 1121 1122 1123 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1120 def list_campaigns(params = {}, = {}) req = build_request(:list_campaigns, params) req.send_request() end |
#list_connect_instance_integrations(params = {}) ⇒ Types::ListConnectInstanceIntegrationsResponse
Provides summary information about the integration under the specified Connect instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1165 1166 1167 1168 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1165 def list_connect_instance_integrations(params = {}, = {}) req = build_request(:list_connect_instance_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
1194 1195 1196 1197 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1194 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
1216 1217 1218 1219 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1216 def pause_campaign(params = {}, = {}) req = build_request(:pause_campaign, params) req.send_request() end |
#put_connect_instance_integration(params = {}) ⇒ Struct
Put or update the integration for the specified Amazon Connect instance.
1253 1254 1255 1256 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1253 def put_connect_instance_integration(params = {}, = {}) req = build_request(:put_connect_instance_integration, params) req.send_request() end |
#put_outbound_request_batch(params = {}) ⇒ Types::PutOutboundRequestBatchResponse
Creates outbound requests for the specified campaign Amazon Connect account. This API is idempotent.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1327 def put_outbound_request_batch(params = {}, = {}) req = build_request(:put_outbound_request_batch, params) req.send_request() end |
#put_profile_outbound_request_batch(params = {}) ⇒ Types::PutProfileOutboundRequestBatchResponse
Takes in a list of profile outbound requests to be placed as part of an outbound campaign. This API is idempotent.
1373 1374 1375 1376 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1373 def put_profile_outbound_request_batch(params = {}, = {}) req = build_request(:put_profile_outbound_request_batch, params) req.send_request() end |
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1395 1396 1397 1398 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1395 def resume_campaign(params = {}, = {}) req = build_request(:resume_campaign, params) req.send_request() end |
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
1417 1418 1419 1420 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1417 def start_campaign(params = {}, = {}) req = build_request(:start_campaign, params) req.send_request() end |
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
1458 1459 1460 1461 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1458 def start_instance_onboarding_job(params = {}, = {}) req = build_request(:start_instance_onboarding_job, params) req.send_request() end |
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
1480 1481 1482 1483 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1480 def stop_campaign(params = {}, = {}) req = build_request(:stop_campaign, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
1508 1509 1510 1511 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1508 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
1534 1535 1536 1537 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1534 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_campaign_channel_subtype_config(params = {}) ⇒ Struct
Updates the channel subtype config of a campaign. This API is idempotent.
1607 1608 1609 1610 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1607 def update_campaign_channel_subtype_config(params = {}, = {}) req = build_request(:update_campaign_channel_subtype_config, params) req.send_request() end |
#update_campaign_communication_limits(params = {}) ⇒ Struct
Updates the communication limits config for a campaign. This API is idempotent.
1644 1645 1646 1647 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1644 def update_campaign_communication_limits(params = {}, = {}) req = build_request(:update_campaign_communication_limits, params) req.send_request() end |
#update_campaign_communication_time(params = {}) ⇒ Struct
Updates the communication time config for a campaign. This API is idempotent.
1739 1740 1741 1742 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1739 def update_campaign_communication_time(params = {}, = {}) req = build_request(:update_campaign_communication_time, params) req.send_request() end |
#update_campaign_flow_association(params = {}) ⇒ Struct
Updates the campaign flow associated with a campaign. This API is idempotent.
1766 1767 1768 1769 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1766 def update_campaign_flow_association(params = {}, = {}) req = build_request(:update_campaign_flow_association, params) req.send_request() end |
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign. This API is idempotent.
1792 1793 1794 1795 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1792 def update_campaign_name(params = {}, = {}) req = build_request(:update_campaign_name, params) req.send_request() end |
#update_campaign_schedule(params = {}) ⇒ Struct
Updates the schedule for a campaign. This API is idempotent.
1822 1823 1824 1825 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1822 def update_campaign_schedule(params = {}, = {}) req = build_request(:update_campaign_schedule, params) req.send_request() end |
#update_campaign_source(params = {}) ⇒ Struct
Updates the campaign source with a campaign. This API is idempotent.
1853 1854 1855 1856 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1853 def update_campaign_source(params = {}, = {}) req = build_request(:update_campaign_source, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1882 1883 1884 |
# File 'lib/aws-sdk-connectcampaignsv2/client.rb', line 1882 def waiter_names [] end |