Class: Aws::ConnectCampaignsV2::Types::EntryLimitsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::EntryLimitsConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Campaign entry limits config
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_entry_count ⇒ Integer
Maximum number of times a participant can enter the campaign.
-
#min_entry_interval ⇒ String
Minimum time interval that must pass before a participant can enter the campaign again.
Instance Attribute Details
#max_entry_count ⇒ Integer
Maximum number of times a participant can enter the campaign. A value of 0 indicates unlimited entries. Values of 1 or greater specify the exact number of entries allowed.
841 842 843 844 845 846 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 841 class EntryLimitsConfig < Struct.new( :max_entry_count, :min_entry_interval) SENSITIVE = [] include Aws::Structure end |
#min_entry_interval ⇒ String
Minimum time interval that must pass before a participant can enter the campaign again.
841 842 843 844 845 846 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 841 class EntryLimitsConfig < Struct.new( :max_entry_count, :min_entry_interval) SENSITIVE = [] include Aws::Structure end |