Class: Aws::ConnectCampaignsV2::Types::PacingStrategy
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::PacingStrategy
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Note:
PacingStrategy is a union - when making an API calls you must set exactly one of the members.
Note:
PacingStrategy is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PacingStrategy corresponding to the set member.
Pacing constraint the dialer may enforce.
Defined Under Namespace
Classes: AbandonmentRate, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abandonment_rate ⇒ Types::AbandonmentRatePacingConfig
Configuration for abandonment-rate-based dialer throttling.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#abandonment_rate ⇒ Types::AbandonmentRatePacingConfig
Configuration for abandonment-rate-based dialer throttling.
1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1629 class PacingStrategy < Struct.new( :abandonment_rate, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AbandonmentRate < PacingStrategy; end class Unknown < PacingStrategy; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1629 1630 1631 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1629 def unknown @unknown end |