Class: Aws::ConnectCampaignsV2::Types::SmsOutboundMode

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connectcampaignsv2/types.rb

Overview

Note:

SmsOutboundMode is a union - when making an API calls you must set exactly one of the members.

Note:

SmsOutboundMode is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SmsOutboundMode corresponding to the set member.

SMS Outbound Mode

Direct Known Subclasses

Agentless, Unknown

Defined Under Namespace

Classes: Agentless, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agentlessTypes::AgentlessConfig

Agentless config



2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2006

class SmsOutboundMode < Struct.new(
  :agentless,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Agentless < SmsOutboundMode; end
  class Unknown < SmsOutboundMode; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2006
2007
2008
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2006

def unknown
  @unknown
end