Class: Aws::ConnectCampaignsV2::Types::TelephonyOutboundMode
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::TelephonyOutboundMode
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Note:
TelephonyOutboundMode is a union - when making an API calls you must set exactly one of the members.
Note:
TelephonyOutboundMode is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TelephonyOutboundMode corresponding to the set member.
Telephony Outbound Mode
Direct Known Subclasses
Defined Under Namespace
Classes: Agentless, Predictive, Preview, Progressive, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agentless ⇒ Types::AgentlessConfig
Agentless config.
-
#predictive ⇒ Types::PredictiveConfig
Predictive config.
-
#preview ⇒ Types::PreviewConfig
Preview config.
-
#progressive ⇒ Types::ProgressiveConfig
Progressive config.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agentless ⇒ Types::AgentlessConfig
Agentless config
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2315 class TelephonyOutboundMode < Struct.new( :progressive, :predictive, :agentless, :preview, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Progressive < TelephonyOutboundMode; end class Predictive < TelephonyOutboundMode; end class Agentless < TelephonyOutboundMode; end class Preview < TelephonyOutboundMode; end class Unknown < TelephonyOutboundMode; end end |
#predictive ⇒ Types::PredictiveConfig
Predictive config
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2315 class TelephonyOutboundMode < Struct.new( :progressive, :predictive, :agentless, :preview, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Progressive < TelephonyOutboundMode; end class Predictive < TelephonyOutboundMode; end class Agentless < TelephonyOutboundMode; end class Preview < TelephonyOutboundMode; end class Unknown < TelephonyOutboundMode; end end |
#preview ⇒ Types::PreviewConfig
Preview config
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2315 class TelephonyOutboundMode < Struct.new( :progressive, :predictive, :agentless, :preview, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Progressive < TelephonyOutboundMode; end class Predictive < TelephonyOutboundMode; end class Agentless < TelephonyOutboundMode; end class Preview < TelephonyOutboundMode; end class Unknown < TelephonyOutboundMode; end end |
#progressive ⇒ Types::ProgressiveConfig
Progressive config
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2315 class TelephonyOutboundMode < Struct.new( :progressive, :predictive, :agentless, :preview, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Progressive < TelephonyOutboundMode; end class Predictive < TelephonyOutboundMode; end class Agentless < TelephonyOutboundMode; end class Preview < TelephonyOutboundMode; end class Unknown < TelephonyOutboundMode; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2315 2316 2317 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 2315 def unknown @unknown end |