Class: Aws::ConnectCampaignsV2::Types::TelephonyOutboundMode
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCampaignsV2::Types::TelephonyOutboundMode
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcampaignsv2/types.rb
Overview
Note:
TelephonyOutboundMode is a union - when making an API calls you must set exactly one of the members.
Note:
TelephonyOutboundMode is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TelephonyOutboundMode corresponding to the set member.
Telephony Outbound Mode
Direct Known Subclasses
Defined Under Namespace
Classes: Agentless, Predictive, Progressive, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agentless ⇒ Types::AgentlessConfig
Agentless config.
-
#predictive ⇒ Types::PredictiveConfig
Predictive config.
-
#progressive ⇒ Types::ProgressiveConfig
Progressive config.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agentless ⇒ Types::AgentlessConfig
Agentless config
1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1941 class TelephonyOutboundMode < Struct.new( :progressive, :predictive, :agentless, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Progressive < TelephonyOutboundMode; end class Predictive < TelephonyOutboundMode; end class Agentless < TelephonyOutboundMode; end class Unknown < TelephonyOutboundMode; end end |
#predictive ⇒ Types::PredictiveConfig
Predictive config
1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1941 class TelephonyOutboundMode < Struct.new( :progressive, :predictive, :agentless, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Progressive < TelephonyOutboundMode; end class Predictive < TelephonyOutboundMode; end class Agentless < TelephonyOutboundMode; end class Unknown < TelephonyOutboundMode; end end |
#progressive ⇒ Types::ProgressiveConfig
Progressive config
1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1941 class TelephonyOutboundMode < Struct.new( :progressive, :predictive, :agentless, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Progressive < TelephonyOutboundMode; end class Predictive < TelephonyOutboundMode; end class Agentless < TelephonyOutboundMode; end class Unknown < TelephonyOutboundMode; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1941 1942 1943 |
# File 'lib/aws-sdk-connectcampaignsv2/types.rb', line 1941 def unknown @unknown end |